#!/bin/bash

## Declarar variables
CONF_FILE=/etc/linkat/linkat-ltsp/linkat-ltsp.conf
PLANTILLES=/usr/share/linkat/linkat-ltsp/plantilles
FILES_LINKAT=/usr/share/linkat/linkat-ltsp/configurador/files
ANSIBLEPLAY=/usr/share/linkat/linkat-ltsp/configurador
LOGS=/var/log/linkat-ltsp.log
DATE=`date '+%Y-%m-%d_%H:%M:%S'`
ARCH='uname -i'
URL_IPXEBIN="http://download-linkat.xtec.cat/distribution/linkat-edu-18.04/dev-extres/ipxe-binaries.tar.gz"

if [ -f "$CONF_FILE" ]; then
  . "$CONF_FILE"
else
  NEW_DEV=""
  NEW_IP="192.168.0.245"
  NEW_MASK="24"
  NEW_GW="192.168.0.1"
  NEW_DNS1="213.176.161.16"
  NEW_DNS2="213.176.161.18"
  NEW_DEV2=""
  NEW_IP2="192.168.50.1"
  NEW_MASK2="24"
fi

## Llista de targetes de xarxa
LIST_DEV=`ip link sh | grep ^[0-9] | grep -v " lo" | cut -d":" -f 2 | tr -d " "`
DEVS=$(echo $LIST_DEV)
## Control d'errors
ERROR="1"
res=""

## Revisar valor de xarxa
check_ip()
{
        echo "$2" | grep -E '^(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9])\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[0-9])$' > /dev/null 2>&1
        if [ "$?" -gt 0 ]; then
		yad --title="Error" --text="\nEl valor $1: $2 no és vàlid." --image="dialog-error" --button="D'acord"
		ERROR="1"
	fi
}

## Revisar connexió
check_connexio()
{
	sudo hping3 -S "$NEW_SERVIDOR_IP" -p 389 -c 4
	if [ $? -eq 0 ]; then
		CONNEXIO="1"
	else
		echo -en "Error de connexió: No s'ha trobat el servidor LDAP"
		exit 12
	fi
}

## Formulari de dades de configuracions del ltsp de centre

formulari()
{
res=$(yad --width=400 --title="Linkat LTSP" --text="\nIntroduïu els valors per configurar el servidor LTSP.\nCal emplenar tots els camps.\n\nConfiguracions del servidor LTSP:\n" \
--image="/usr/share/linkat/linkat-ltsp/linkat-ltsp-banner.png" \
--form --item-separator=" " \
--field="Targeta de xarxa a Internet":CBE \
--field="IP del servidor LTSP" \
--field="Màscara de xarxa" \
--field="Passarel·la" \
--field="DNS Primària" \
--field="DNS Secundària" \
--field="Targeta de xarxa dels clients":CBE \
--field="IP interna del servidor LTSP" \
--field="Màscara de xarxa interna" \
--button="D'acord" --button="Cancel·la":11 \
"$DEVS" "$NEW_IP" "$NEW_MASK" "$NEW_GW" "$NEW_DNS1" "$NEW_DNS2" "$DEVS" "$NEW_IP2" "$NEW_MASK2")

res1="$?"

if [ "$res1" -gt 1 ]; then
	exit 1
fi

NEW_DEV=$(echo "$res" | awk -F"|" '{print $1}')
NEW_IP=$(echo "$res" | awk -F"|" '{print $2}')
NEW_MASK=$(echo "$res" | awk -F"|" '{print $3}')
NEW_GW=$(echo "$res" | awk -F"|" '{print $4}')
NEW_DNS1=$(echo "$res" | awk -F"|" '{print $5}')
NEW_DNS2=$(echo "$res" | awk -F"|" '{print $6}')
NEW_DEV2=$(echo "$res" | awk -F"|" '{print $7}')
NEW_IP2=$(echo "$res" | awk -F"|" '{print $8}')
NEW_MASK2=$(echo "$res" | awk -F"|" '{print $9}')
SUBIP1=$(echo $NEW_IP2 | awk -F. '{print $1}')
SUBIP2=$(echo $NEW_IP2 | awk -F. '{print $2}')
SUBIP3=$(echo $NEW_IP2 | awk -F. '{print $3}')
}

check_errors()
{
if [ ! "$?" -eq 0 ]; then
	echo -en "Error: $1"
	yad --title="Error" --text="\nS'ha produit un error durant la instal·lacio de: $1.\nEl programa es tancara." --image="dialog-error" --button="D'acord"
	exit 22
fi
}

validar_formulari()
{
yad --width=400 --title="Linkat LTSP" --text="\nLes dades següents són correctes?\n\nTargeta de xarxa a Internet: $NEW_DEV\nIP del servidor LTSP: $NEW_IP\n:Màscara de xarxa $NEW_MASK\nPassarel·la: $NEW_GW\nDNS Primària: $NEW_DNS1\nDNS Secundària: $NEW_DNS2\nTargeta de xarxa dels clients: $NEW_DEV2\nIP interna del servidor LTSP: $NEW_IP2\nMàcara de xarxa interna: $NEW_MASK2" \
	--image="/usr/share/linkat/linkat-ltsp/linkat-ltsp-banner.png" \
	--button="D'acord" --button="Cancel·la":11
res1="$?"

if [ "$res1" -gt 1 ]; then
        ERROR="1"
fi
}

ERROR="1"

while [ "$ERROR" -eq "1" ]
do
	ERROR="0"
	formulari
	check_ip IP "$NEW_IP"
	check_ip IP "$NEW_IP2"
	check_ip Passarel·la "$NEW_GW"
	check_ip DNS "$NEW_DNS1"
	check_ip DNS "$NEW_DNS2"
	if [ "$ERROR" -eq 0 ]; then
                validar_formulari
        fi
done


function validate_url(){
  if [[ `wget -S --spider $URL_IPXEBIN  2>&1 | grep 'HTTP/1.1 200 OK'` ]]; then
    return 0
  else
    return 1
  fi
}

ltsp_ipxe () {
if validate_url ; then
        wget $URL_IPXEBIN --directory-prefix /tmp
        cd /tmp
        tar xvfz ipxe-binaries.tar.gz
        cp -v /tmp/ipxe-binaries/* /srv/tftp/ltsp/
        rm -r /tmp/ipxe-binaries*
	ltsp ipxe
  else
        echo "La descàrrega de binaris 'ipxe' no està disponible. Revisa la connectivitat"
fi
}



## Backup del fitxer de configuració linkat-ltsp.conf
if [ -f "$CONF_FILE" ]; then
	cp -av "$CONF_FILE" "$CONF_FILE"."$DATE"
fi

## Genera nou fitxer de configuració linkat-ltsp.conf
echo "$DATE" > $CONF_FILE
echo "NEW_DEV=$NEW_DEV" >> $CONF_FILE
echo "NEW_IP=$NEW_IP" >> $CONF_FILE
echo "NEW_MASK=$NEW_MASK" >> $CONF_FILE
echo "NEW_GW=$NEW_GW" >> $CONF_FILE
echo "NEW_DNS1=$NEW_DNS1" >> $CONF_FILE
echo "NEW_DNS2=$NEW_DNS2" >> $CONF_FILE
echo "NEW_DEV2=$NEW_DEV2" >> $CONF_FILE
echo "NEW_IP2=$NEW_IP2" >> $CONF_FILE
echo "NEW_MASK2=$NEW_MASK2" >> $CONF_FILE

## Copia plantilles per modificar
rm -rf "$FILES_LINKAT"/*
cp -av "$PLANTILLES"/* "$FILES_LINKAT"/

cd "$FILES_LINKAT"/

## Modifica variables

sed -i s/__DEV__/"$NEW_DEV"/g *
sed -i s/__IP__/"$NEW_IP"/g *
sed -i s/__MASK__/"$NEW_MASK"/g *
sed -i s/__GW__/"$NEW_GW"/g *
sed -i s/__DNS1__/"$NEW_DNS1"/g *
sed -i s/__DNS2__/"$NEW_DNS2"/g *
sed -i s/__DEV2__/"$NEW_DEV2"/g *
sed -i s/__IP2__/"$NEW_IP2"/g *
sed -i s/__MASK2__/"$NEW_MASK2"/g *
sed -i s/__SUBIP1__/"$SUBIP1"/g *
sed -i s/__SUBIP2__/"$SUBIP2"/g *
sed -i s/__SUBIP3__/"$SUBIP3"/g *

echo "$DATE" >> "$LOGS"

## Aplica configuracions
echo -en "Aplicant configuracions...\n\n"

ltsp image /
ltsp image $ARCH
validate_url
ltsp_ipxe
ltsp ltsp nfs
ltsp initrd

#ltsp-config dnsmasq --no-proxy-dhcp --overwrite > /dev/null 2>&1

## Aplica ANSIBLE
ansible-playbook "$ANSIBLEPLAY"/ltsp.yml

/usr/share/linkat/linkat-ltsp/configurador/files/iptables.sh

## Desactivar NetworkManager
sudo systemctl stop NetworkManager.service
sudo systemctl disable NetworkManager.service
if [ -f /lib/systemd/system/NetworkManager.service ]; then
        mv /lib/systemd/system/NetworkManager.service /lib/systemd/system/NetworkManager.service.ori
fi

yad --width=300 --title="Linkat LTSP" --text="\nLa configuració ha estat aplicada.\n\nEl servidor LTSP s'ha de reiniciar per aplicar els canvis.\n\nVoleu reiniciar-lo ara?" \
	--image="/usr/share/linkat/linkat-ltsp/linkat-ltsp-banner.png" \
	--button="D'acord" --button="Cancel·la":11
if [ $? -eq 0 ]; then
        sudo shutdown -r now
fi
